@@ -21,13 +21,13 @@
 
 #include "exception.h"
 
-BridgeServerBase::BridgeServerBase(quint16 port, QObject *parent) :
-    QObject(parent),
+BridgeServerBase::BridgeServerBase( quint16 port, QObject *parent )
+  : QObject( parent ),
     m_server( new QTcpServer( this ) )
 {
-  connect( m_server, SIGNAL(newConnection()), SLOT(slotNewConnection()) );
+  connect( m_server, SIGNAL( newConnection() ), SLOT( slotNewConnection() ) );
   if ( !m_server->listen( QHostAddress::Any, port ) )
-      throw Exception<std::runtime_error>( tr("Can't listen to port %1: %2")
+      throw Exception<std::runtime_error>( tr( "Can't listen to port %1: %2" )
                                            .arg( port ).arg( m_server->errorString() ) );
 }
 
