@@ -90,6 +90,11 @@ class ProcessControl : public QObject
      */
     void processErrorMessages( const QString &errorMsg );
 
+    /**
+     * This signal is emitted when the server is restarted after a crash.
+     */
+    void restarted();
+
     /**
      * Emitted if the process could not be started since it terminated
      * too often.
@@ -99,8 +104,6 @@ class ProcessControl : public QObject
   private Q_SLOTS:
     void slotError( QProcess::ProcessError );
     void slotFinished( int, QProcess::ExitStatus );
-    void slotErrorMessages();
-    void slotStdoutMessages();
     void resetCrashCount();
 
   private:
