@@ -34,10 +34,14 @@
 #include "storage/itemretrievalthread.h"
 #include "preprocessormanager.h"
 #include "search/searchmanager.h"
+#include "xesamtypes.h"
 
 #include "libs/xdgbasedirs_p.h"
 #include "libs/protocol_p.h"
 
+#include <QtSql/QSqlQuery>
+#include <QtSql/QSqlError>
+
 #include <QtCore/QCoreApplication>
 #include <QtCore/QDir>
 #include <QtCore/QSettings>
@@ -55,7 +59,11 @@ using namespace Akonadi;
 static AkonadiServer *s_instance = 0;
 
 AkonadiServer::AkonadiServer( QObject* parent )
+#ifdef Q_OS_WINCE
+    : QTcpServer( parent )
+#else
     : QLocalServer( parent )
+#endif
     , mCacheCleaner( 0 )
     , mIntervalChecker( 0 )
     , mItemRetrievalThread( 0 )
@@ -72,6 +80,8 @@ AkonadiServer::AkonadiServer( QObject* parent )
     else
       createDatabase();
 
+    DbConfig::configuredDatabase()->setup();
+
     s_instance = this;
 
     const QString connectionSettingsFile = XdgBaseDirs::akonadiConnectionConfigFile( XdgBaseDirs::WriteOnly );
@@ -79,7 +89,11 @@ AkonadiServer::AkonadiServer( QObject* parent )
 
 #ifdef Q_OS_WIN
     QString namedPipe = settings.value( QLatin1String( "Connection/NamedPipe" ), QLatin1String( "Akonadi" ) ).toString();
+#ifdef Q_OS_WINCE
+    if ( !listen( QHostAddress::LocalHost, 31414 ) )
+#else
     if ( !listen( namedPipe ) )
+#endif
       akFatal() << "Unable to listen on Named Pipe" << namedPipe;
 
     connectionSettings.setValue( QLatin1String( "Data/Method" ), QLatin1String( "NamedPipe" ) );
@@ -126,7 +140,12 @@ AkonadiServer::AkonadiServer( QObject* parent )
     mItemRetrievalThread->start( QThread::HighPriority );
 
     const QStringList searchManagers = settings.value( QLatin1String( "Search/Manager" ),
-                                                       QStringList() << QLatin1String( "Nepomuk" )
+                                                       QStringList()
+#ifdef AKONADI_USE_STRIGI_SEARCH
+                                                                     << QLatin1String( "Xesam" )
+#else
+                                                                     << QLatin1String( "Nepomuk" )
+#endif
                                                                      << QLatin1String( "Agent" ) ).toStringList();
     mSearchManager = new SearchManager( searchManagers, this );
 
@@ -151,6 +170,8 @@ AkonadiServer::AkonadiServer( QObject* parent )
     // for the items as we don't actually know at which stage the
     // operation was interrupted...
     db->unhideAllPimItems();
+
+    qDBusRegisterMetaType<XesamVariantListVector>();
 }
 
 AkonadiServer::~AkonadiServer()
@@ -216,7 +237,11 @@ void AkonadiServer::doQuit()
     QCoreApplication::exit();
 }
 
+#ifdef Q_OS_WINCE
+void AkonadiServer::incomingConnection( int socketDescriptor )
+#else
 void AkonadiServer::incomingConnection( quintptr socketDescriptor )
+#endif
 {
     if ( mAlreadyShutdown )
       return;
@@ -267,7 +292,7 @@ void AkonadiServer::createDatabase()
     if ( db.open() ) {
       {
         QSqlQuery query( db );
-        if ( !query.exec( QLatin1String( "CREATE DATABASE akonadi" ) ) ) {
+        if ( !query.exec( QString::fromLatin1( "CREATE DATABASE %1" ).arg( DbConfig::configuredDatabase()->databaseName() ) ) ) {
           akError() << "Failed to create database";
           akError() << "Query error:" << query.lastError().text();
           akFatal() << "Database error:" << db.lastError().text();
