@@ -36,6 +36,7 @@
 #include "storage/parthelper.h"
 #include "storage/transaction.h"
 #include "utils.h"
+#include "intervalcheck.h"
 
 #include <QtCore/QLocale>
 #include <QtCore/QStringList>
@@ -266,7 +267,9 @@ bool FetchHelper::parseStream( const QByteArray &responseIdentifier )
       attributes.append( "DATETIME " + ImapParser::quote( datetime.toUtf8() ) );
     }
     if ( mRemoteRevisionRequested ) {
-      attributes.append( "REMOTEREVISION " + ImapParser::quote( Utils::variantToByteArray( itemQuery.value( ItemQueryRemoteRevisionColumn ) ) ) );
+      const QByteArray rrev = Utils::variantToByteArray( itemQuery.value( ItemQueryRemoteRevisionColumn ) );
+      if ( !rrev.isEmpty() )
+        attributes.append( "REMOTEREVISION " + ImapParser::quote( rrev ) );
     }
 
     if ( mRequestedParts.contains( "FLAGS" ) ) {
@@ -369,7 +372,7 @@ void FetchHelper::triggerOnDemandFetch()
   if ( !collection.cachePolicySyncOnDemand() )
     return;
 
-  ItemRetrievalManager::instance()->requestCollectionSync( collection );
+  IntervalCheck::instance()->requestCollectionSync( collection );
 }
 
 void FetchHelper::parseCommandStream()
