@@ -22,13 +22,12 @@
 
 #include <QtCore/QHash>
 #include <QtCore/QPair>
+#include <QtCore/QVector>
 #include <QtCore/QStringList>
 #include <QtSql/QSqlDatabase>
 
 #include <boost/shared_ptr.hpp>
 
-#include "../akonadiprivate_export.h"
-
 class QDomElement;
 
 class DebugInterface
@@ -43,7 +42,7 @@ class DebugInterface
  * the file name of a template file and initializes the database
  * according to the rules in the template file.
  */
-class AKONADIPRIVATE_EXPORT DbInitializer
+class DbInitializer
 {
   public:
    typedef boost::shared_ptr<DbInitializer> Ptr;
@@ -128,9 +127,9 @@ class AKONADIPRIVATE_EXPORT DbInitializer
         TableDescription();
 
         QString name;
-        QList<ColumnDescription> columns;
-        QList<IndexDescription> indexes;
-        QList<DataDescription> data;
+        QVector<ColumnDescription> columns;
+        QVector<IndexDescription> indexes;
+        QVector<DataDescription> data;
     };
 
     /**
