@@ -155,6 +155,8 @@ bool DbUpdater::updateApplicable( const QString &backends ) const
     currentBackend = QLatin1String( "psql" );
   else if ( m_database.driverName().startsWith( QLatin1String( "QSQLITE" ) ) ) // QSQLITE or QSQLITE3
     currentBackend = QLatin1String( "sqlite" );
+  else if ( m_database.driverName() == QLatin1String( "QODBC" ) )
+    currentBackend = QLatin1String( "odbc" );
 
   return matchingBackends.contains( currentBackend );
 }
