@@ -22,11 +22,17 @@
 #include <QtCore/QDebug>
 #include <QtCore/QVariant>
 #include <QBuffer>
+#include <QDir>
 
 #include "storage/dbupdater.h"
 
 QTEST_MAIN( DbUpdaterTest )
 
+void DbUpdaterTest::initTestCase()
+{
+  Q_INIT_RESOURCE( akonadidb );
+}
+
 void DbUpdaterTest::testMysqlUpdateStatements()
 {
   const QSqlDatabase db = QSqlDatabase::addDatabase( QLatin1String( "QMYSQL" ) );
@@ -114,4 +120,9 @@ void DbUpdaterTest::testPsqlUpdateStatements()
   QCOMPARE( updateSets.value( 17 ).statements.count(), 0 );
 }
 
+void DbUpdaterTest::cleanupTestCase()
+{
+  Q_CLEANUP_RESOURCE( akonadidb );
+}
+
 #include "dbupdatertest.moc"
